@@ -58,3 +58,19 @@ test_that("is_url() tests whether path is URL", {
   expect_false(is_url("http:/example.com"))
   expect_true(is_url("ftps://example.com")) # Not a correct protocol
 })
+
+test_that("get_dot_names() returns the names passed via ...", {
+  test_fn <- function(...) {
+    get_dot_names(...)
+  }
+  expect_identical(test_fn(a = "1", b = "2"), c("a", "b"))
+})
+
+test_that("get_dot_names() does not return empty strings for unnamed args passed
+           to ellipsis", {
+  test_fn <- function(...) {
+    get_dot_names(...)
+  }
+  expect_identical(test_fn(a = "1", "2", b = "3", c = "4"), c("a", "b", "c"))
+  expect_length(test_fn(a = "1", "2", b = "3", c = "4"), 3)
+})
